==> agiflow_sdk-0.0.17.tar.gz: agiflow_sdk-0.0.17/agiflow/opentelemetry/instrumentation/groq/instrumentation.py <==
"""
Copyright (c) 2024 Agiflow

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from typing import Collection

from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from opentelemetry.trace import get_tracer
from wrapt import wrap_function_wrapper
from agiflow.opentelemetry.instrumentation.utils import (
  stream_wrapper,
  async_stream_wrapper,
)

from agiflow.opentelemetry.instrumentation.groq.hooks import (
  ChatCompletionSpanCapture,
)
from agiflow.version import __version__


class GroqInstrumentation(BaseInstrumentor):
    """
    The GroqInstrumentation class represents the Groq instrumentation
    """

    def instrumentation_dependencies(self) -> Collection[str]:
        return ["groq >= 0.5.0"]

    def _instrument(self, **kwargs):
        tracer_provider = kwargs.get("tracer_provider")
        tracer = get_tracer(__name__, __version__, tracer_provider)

        wrap_function_wrapper(
            "groq.resources.chat.completions",
            "Completions.create",
            stream_wrapper(
              tracer=tracer,
              SpanCapture=ChatCompletionSpanCapture
            )
        )

        wrap_function_wrapper(
            "groq.resources.chat.completions",
            "AsyncCompletions.create",
            async_stream_wrapper(
              tracer=tracer,
              SpanCapture=ChatCompletionSpanCapture
            )
        )

    def _instrument_module(self, module_name):
        pass

    def _uninstrument(self, **kwargs):
        pass

==> agiflow_sdk-0.0.22.tar.gz: agiflow_sdk-0.0.22/agiflow/opentelemetry/instrumentation/groq/instrumentation.py <==
"""
Copyright (c) 2024 Agiflow

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from typing import Collection

from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from opentelemetry.trace import get_tracer
from wrapt import wrap_function_wrapper
from agiflow.opentelemetry.instrumentation.utils import (
  stream_wrapper,
  async_stream_wrapper,
)
from agiflow.version import __version__
from .hooks import (
  ChatCompletionSpanCapture,
)


class GroqInstrumentation(BaseInstrumentor):
    """
    The GroqInstrumentation class represents the Groq instrumentation
    """

    def instrumentation_dependencies(self) -> Collection[str]:
        return ["groq >= 0.5.0"]

    def _instrument(self, **kwargs):
        tracer_provider = kwargs.get("tracer_provider")
        tracer = get_tracer(__name__, __version__, tracer_provider)

        wrap_function_wrapper(
            "groq.resources.chat.completions",
            "Completions.create",
            stream_wrapper(
              tracer=tracer,
              SpanCapture=ChatCompletionSpanCapture
            )
        )

        wrap_function_wrapper(
            "groq.resources.chat.completions",
            "AsyncCompletions.create",
            async_stream_wrapper(
              tracer=tracer,
              SpanCapture=ChatCompletionSpanCapture
            )
        )

    def _instrument_module(self, module_name):
        pass

    def _uninstrument(self, **kwargs):
        pass
